@@ -315,6 +315,7 @@ impl PanelState for BrowserState {
     fn on_internal(
         &mut self,
         w: &mut W,
+        invocation_parser: Option<&InvocationParser>,
         internal_exec: &InternalExecution,
         input_invocation: Option<&VerbInvocation>,
         trigger_type: TriggerType,
@@ -612,6 +613,7 @@ impl PanelState for BrowserState {
             Internal::quit => CmdResult::Quit,
             _ => self.on_internal_generic(
                 w,
+                invocation_parser,
                 internal_exec,
                 input_invocation,
                 trigger_type,
