@@ -38,7 +38,17 @@ impl VerbStore {
     pub fn new(conf: &mut Conf) -> Result<Self, ConfError> {
         let mut store = Self { verbs: Vec::new() };
         for vc in &conf.verbs {
-            store.add_from_conf(vc)?;
+            if let Err(e) = store.add_from_conf(vc) {
+                eprintln!("Invalid verb configuration: {}", e);
+                warn!("Faulty parsed configuration: {:#?}", vc);
+                if let Ok(toml) = toml::to_string(&vc) {
+                    eprintln!("Faulty configuration:\n{}", toml);
+                }
+                eprintln!("Configuration files:");
+                for path in &conf.files {
+                    eprintln!("  - {}", path.display());
+                }
+            }
         }
         store.add_builtin_verbs(); // at the end so that we can override them
         Ok(store)
@@ -301,6 +311,9 @@ impl VerbStore {
         self.add_internal(trash);
         self.add_internal(total_search).with_key(key!(ctrl-s));
         self.add_internal(up_tree).with_shortcut("up");
+
+        self.add_internal(clear_output);
+        self.add_internal(write_output);
     }
 
     fn build_add_internal(
